package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class KeyTransRecipientInfo extends ASN1Encodable {
   private DERInteger version;
   private RecipientIdentifier rid;
   private AlgorithmIdentifier keyEncryptionAlgorithm;
   private ASN1OctetString encryptedKey;

   public KeyTransRecipientInfo(RecipientIdentifier rid, AlgorithmIdentifier keyEncryptionAlgorithm, ASN1OctetString encryptedKey) {
      DERInteger var4;
      if (rid.getDERObject() instanceof ASN1TaggedObject) {
         var4 = new DERInteger.<init>(2);
         this.version = var4;
      } else {
         var4 = new DERInteger.<init>(0);
         this.version = var4;
      }

      this.rid = rid;
      this.keyEncryptionAlgorithm = keyEncryptionAlgorithm;
      this.encryptedKey = encryptedKey;
   }

   public KeyTransRecipientInfo(ASN1Sequence seq) {
      this.version = (DERInteger)seq.getObjectAt(0);
      this.rid = RecipientIdentifier.getInstance(seq.getObjectAt(1));
      this.keyEncryptionAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(2));
      this.encryptedKey = (ASN1OctetString)seq.getObjectAt(3);
   }

   public static KeyTransRecipientInfo getInstance(Object obj) {
      if (obj != null && !(obj instanceof KeyTransRecipientInfo)) {
         if (obj instanceof ASN1Sequence) {
            return new KeyTransRecipientInfo((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Illegal object in KeyTransRecipientInfo: " + obj.getClass().getName());
         }
      } else {
         return (KeyTransRecipientInfo)obj;
      }
   }

   public DERInteger getVersion() {
      return this.version;
   }

   public RecipientIdentifier getRecipientIdentifier() {
      return this.rid;
   }

   public AlgorithmIdentifier getKeyEncryptionAlgorithm() {
      return this.keyEncryptionAlgorithm;
   }

   public ASN1OctetString getEncryptedKey() {
      return this.encryptedKey;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.version);
      var1.add(this.rid);
      var1.add(this.keyEncryptionAlgorithm);
      var10000.add(this.encryptedKey);
      return new DERSequence(var1);
   }
}
